#[non_exhaustive]pub enum SandboxError {
CgroupUnavailable(String),
CgroupIo(Error),
CgroupNotWritable {
path: String,
},
CgroupParseFailed(String),
RegistryFull {
max_tracked: usize,
},
ProcessNotFound {
pid: u32,
},
RuntimeNotFound {
name: String,
},
RuntimeFailed {
reason: String,
},
SignalFailed {
pid: u32,
reason: String,
},
ApprovalDenied {
operation: String,
},
SerdeError(Error),
Unsupported(String),
}Expand description
Errors produced by sandbox operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
cgroup v2 is not available on this system (non-systemd or pre-unified hierarchy kernel).
CgroupIo(Error)
A filesystem I/O error occurred while manipulating cgroupfs.
CgroupNotWritable
The discovered cgroup path is not writable by the current user.
CgroupParseFailed(String)
Failed to parse /proc/self/cgroup.
RegistryFull
A process registry limit was exceeded.
ProcessNotFound
The requested PID was not found in the registry.
RuntimeNotFound
No OCI container runtime could be found on $PATH.
RuntimeFailed
The container runtime exited with a non-zero status or failed to start.
SignalFailed
A signal could not be sent to the target process.
ApprovalDenied
An approval callback denied the operation.
SerdeError(Error)
Serialization or deserialization error when communicating with the init binary.
Unsupported(String)
Generic platform error for unsupported operations.