pub struct CapturedOutput { /* private fields */ }Expand description
Captured stdout/stderr from a non-interactive sandbox process.
Wraps a tempfile::TempDir that is automatically removed when the last
Arc<CapturedOutput> is dropped (either from the ProcessCapture handle
or from the ProcessRecord in the registry).
Implementations
Sourceimpl CapturedOutput
impl CapturedOutput
Sourcepub fn new(mode: OutputMode) -> Result<Self>
pub fn new(mode: OutputMode) -> Result<Self>
Allocate a new output capture directory.
Errors
Returns an std::io::Error if the directory cannot be created.
Sourcepub fn stdout_path(&self) -> PathBuf
pub fn stdout_path(&self) -> PathBuf
Path to the stdout output file (or combined output file).
Sourcepub fn stderr_path(&self) -> Option<PathBuf>
pub fn stderr_path(&self) -> Option<PathBuf>
Path to the stderr output file, or None when streams are combined.
Sourcepub fn read_stdout(&self) -> Result<String>
pub fn read_stdout(&self) -> Result<String>
Read captured stdout (or combined output) as a UTF-8 string.
Returns an empty string if the file does not yet exist (process has not produced any output).
Errors
Returns an std::io::Error if the file exists but cannot be read.
Sourcepub fn read_stderr(&self) -> Result<Option<String>>
pub fn read_stderr(&self) -> Result<Option<String>>
Read captured stderr as a UTF-8 string.
Returns None when using OutputMode::Combined (use
read_stdout instead). Returns an empty string if
the stderr file does not yet exist.
Errors
Returns an std::io::Error if the file exists but cannot be read.
Sourcepub const fn mode(&self) -> OutputMode
pub const fn mode(&self) -> OutputMode
The capture mode.