Process tracking plugin, command execution tools, and shell session tools.
ProcessPlugin contributes five management tools (list_processes,
kill_process, process_stats, wait_for_process, read_process_output).
CommandPlugin contributes four execution tools (run_command,
open_shell, shell_write, shell_read) that spawn and interact with
sandboxed processes.
Re-exports
pub use context::SandboxContext;pub use process_plugin::ProcessPlugin;pub use process_plugin::ProcessPluginKey;pub use process_plugin::ProcessPluginState;
Modules
- command_
tools - LLM-callable tools for spawning and interacting with sandboxed commands.
- context
- Shared context for sandbox tools that need to spawn processes.
- expect_
engine - Expect engine backed by
expectrl— implements goexpect-equivalent semantics. - process_
plugin ProcessPlugin— exposes process management and command execution as LLM tools.- tools
- LLM-callable tools for process management.