pub struct WaitForProcessTool { /* private fields */ }Expand description
LLM tool: wait for a process to finish and return its exit status.
Polls the registry every 200 ms until the process is no longer running or
the timeout expires. Requires that
monitor_child was called so the
registry is updated automatically when the process exits.
Implementations
Sourceimpl WaitForProcessTool
impl WaitForProcessTool
Sourcepub const fn new(scope: ProcessVisibilityScope) -> Self
pub const fn new(scope: ProcessVisibilityScope) -> Self
Create a new wait_for_process tool.